@@ -21,6 +21,7 @@ from .model.friends import Friends
 from .plot.friends import plotMonthlyFriendsCreated
 from .model.comments import Comments
 from .plot.comments import plotTopXPeersWithMostCommentedPostsByUser
+from .plot.extra import plotWeeklyHeatMapWithLikesReactionsComments
 from time import time
 
 
@@ -42,7 +43,7 @@ def _getBanner():
     '''
         Prints banner of scipt
     '''
-    print('\x1b[1;6;36;49m[+]fviz v0.6.0 - Facebook data visualizer\x1b[0m\n\n\t\x1b[3;30;47m$ fviz `path-to-exported-facebook-data.zip` `path-for-zip-extraction`  `path-to-sink-directory`\x1b[0m\n\n[+]Author: Anjan Roy < anjanroy@yandex.com >\n[+]Source: https://github.com/itzmeanjan/fviz ( MIT Licensed )\n')
+    print('\x1b[1;6;36;49m[+]fviz v0.7.0 - Facebook data visualizer\x1b[0m\n\n\t\x1b[3;30;47m$ fviz `path-to-exported-facebook-data.zip` `path-for-zip-extraction`  `path-to-sink-directory`\x1b[0m\n\n[+]Author: Anjan Roy < anjanroy@yandex.com >\n[+]Source: https://github.com/itzmeanjan/fviz ( MIT Licensed )\n')
 
 
 def _getCMD() -> Tuple[str, str, str]:
@@ -165,6 +166,17 @@ def main():
                     'accumulatedAcivityInEachMinuteOfDayBy{}.svg'.format(
                         _splitAndJoinActorName(reactions.reactions[0].actor)
                     ))),
+            plotWeeklyHeatMapWithLikesReactionsComments(
+                reactions,
+                comments,
+                'Facebook Activity on each Quarter of Day by {}'.format(
+                    reactions.reactions[0].actor),
+                join(
+                    sink,
+                    'facebookActivityOnEachQuarterOfDayBy{}.svg'.format(
+                        _splitAndJoinActorName(
+                            reactions.reactions[0].actor)
+                    ))),
             plotMonthlyFriendsCreated(
                 friends,
                 'Monthly Friending Rate of {}'.format(
